pub enum AccountState<'a> {
Dead,
Alive(&'a AccountSharedData),
}This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
The state the account is in initially, before transaction processing
Variants
Dead
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
This account is dead, and will be created by this transaction
Alive(&'a AccountSharedData)
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
This account is alive, and already existed prior to this transaction